## Typing stubs for netaddr

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`netaddr`](https://github.com/drkjam/netaddr) package. It can be used by type checkers
to check code that uses `netaddr`. This version of
`types-netaddr` aims to provide accurate annotations for
`netaddr==1.3.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/netaddr`](https://github.com/python/typeshed/tree/main/stubs/netaddr)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.17.1
* [pyright](https://github.com/microsoft/pyright) 1.1.404

It was generated from typeshed commit
[`ca44e4c45dc40fb47602dc79a3145ba61879add8`](https://github.com/python/typeshed/commit/ca44e4c45dc40fb47602dc79a3145ba61879add8).